from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Connector:
	"""Connector commands group definition. 1 total commands, 1 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("connector", core, parent)

	@property
	def translation(self):
		"""translation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_translation'):
			from .Connector_.Translation import Translation
			self._translation = Translation(self._core, self._base)
		return self._translation

	def clone(self) -> 'Connector':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Connector(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
